==> generator-angular-neat-0.0.10.tgz: package/app/index.js <==
'use strict';
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');

module.exports = yeoman.generators.Base.extend({
  initializing: function () {
    this.pkg = require('../package.json');
  },

  prompting: function () {
    var done = this.async();

    // Have Yeoman greet the user.
    this.log(yosay(
      'Welcome to the stylish ' + chalk.red('AngularNeat') + ' generator!'
    ));

    var projectPath = this.destinationRoot();

    var prompts = [{
      name: 'appName',
      message: 'What is the name of this app?',
      default: function() {
        return projectPath.split('/').pop();
      }
    }];

    this.prompt(prompts, function (props) {
      this.appName = props.appName;

      done();
    }.bind(this));
  },

  createFolders: function() {
    this.mkdir('app');
    this.mkdir('app/styles');
    this.mkdir('app/scripts');
    this.mkdir('app/scripts/controllers');
    this.mkdir('app/images');
    this.mkdir('app/views');
    this.mkdir('build');
    this.mkdir('test');
    this.mkdir('test/spec');
    this.mkdir('test/spec/controllers');
  },

  writing: {
    app: function () {

      var context = {
        appName: this.appName
      };

      // Copy Build-Related Files
      this.fs.copy(
        this.templatePath('build/*'),
        this.destinationPath('build/')
      );

      // Copy Project Assets
      this.fs.copyTpl(
        this.templatePath('_package.json'),
        this.destinationPath('package.json'),
        context
      );
      this.fs.copyTpl(
        this.templatePath('_bower.json'),
        this.destinationPath('bower.json'),
        context
      );
      this.fs.copy(
        this.templatePath('_travis.yml'),
        this.destinationPath('travis.yml')
      );
      this.fs.copy(
        this.templatePath('_Gruntfile.js'),
        this.destinationPath('Gruntfile.js')
      );
      this.fs.copy(
        this.templatePath('bowerrc'),
        this.destinationPath('.bowerrc')
      );
      this.fs.copy(
        this.templatePath('karma.conf.js'),
        this.destinationPath('test/karma.conf.js')
      );
      this.fs.copyTpl(
        this.templatePath('_home-spec.js'),
        this.destinationPath('test/spec/controllers/home-spec.js'),
        context
      );
      this.fs.copyTpl(
        this.templatePath('_login-spec.js'),
        this.destinationPath('test/spec/controllers/login-spec.js'),
        context
      );

      // Copy App Assets: Root
      this.fs.copy(
        this.templatePath('_app.js'),
        this.destinationPath('app/scripts/app.js')
      );
      this.fs.copy(
        this.templatePath('_index.html'),
        this.destinationPath('app/index.html')
      );
      this.fs.copy(
        this.templatePath('robots.txt'),
        this.destinationPath('app/robots.txt')
      );

      // Copy App Assets: Controllers
      this.fs.copy(
        this.templatePath('controllers/*'),
        this.destinationPath('app/scripts/controllers/')
      );

      // Copy App Assets: Styles
      this.fs.copy(
        this.templatePath('_main.less'),
        this.destinationPath('app/styles/main.less')
      );
      this.fs.copy(
        this.templatePath('csslintrc'),
        this.destinationPath('.csslintrc')
      );

      // Copy App Assets: Views
      this.fs.copy(
        this.templatePath('views/*'),
        this.destinationPath('app/views/')
      );
    },

    projectfiles: function () {
      this.fs.copy(
        this.templatePath('editorconfig'),
        this.destinationPath('.editorconfig')
      );
      this.fs.copy(
        this.templatePath('jshintrc'),
        this.destinationPath('.jshintrc')
      );
    }
  },

  install: function () {
    this.installDependencies({
      skipInstall: this.options['skip-install']
    });
  }
});

==> generator-angular-neat-0.0.11.tgz: package/app/index.js <==
'use strict';
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');

module.exports = yeoman.generators.Base.extend({
  initializing: function () {
    this.pkg = require('../package.json');
  },

  prompting: function () {
    var done = this.async();

    // Have Yeoman greet the user.
    this.log(yosay(
      'Welcome to the stylish ' + chalk.red('AngularNeat') + ' generator!'
    ));

    var projectPath = this.destinationRoot();

    var prompts = [{
      name: 'appName',
      message: 'What is the name of this app?',
      default: function() {
        return projectPath.split('/').pop();
      }
    }];

    this.prompt(prompts, function (props) {
      this.appName = props.appName;

      done();
    }.bind(this));
  },

  createFolders: function() {
    this.mkdir('app');
    this.mkdir('app/styles');
    this.mkdir('app/scripts');
    this.mkdir('app/scripts/controllers');
    this.mkdir('app/images');
    this.mkdir('app/views');
    this.mkdir('build');
    this.mkdir('test');
    this.mkdir('test/spec');
    this.mkdir('test/spec/controllers');
  },

  writing: {
    app: function () {

      var context = {
        appName: this.appName
      };

      // Copy Build-Related Files
      this.fs.copy(
        this.templatePath('build/*'),
        this.destinationPath('build/')
      );

      // Copy Project Assets
      this.fs.copyTpl(
        this.templatePath('_package.json'),
        this.destinationPath('package.json'),
        context
      );
      this.fs.copyTpl(
        this.templatePath('_bower.json'),
        this.destinationPath('bower.json'),
        context
      );
      this.fs.copy(
        this.templatePath('_travis.yml'),
        this.destinationPath('travis.yml')
      );
      this.fs.copy(
        this.templatePath('_Gruntfile.js'),
        this.destinationPath('Gruntfile.js')
      );
      this.fs.copy(
        this.templatePath('bowerrc'),
        this.destinationPath('.bowerrc')
      );
      this.fs.copy(
        this.templatePath('karma.conf.js'),
        this.destinationPath('test/karma.conf.js')
      );
      this.fs.copyTpl(
        this.templatePath('_home-spec.js'),
        this.destinationPath('test/spec/controllers/home-spec.js'),
        context
      );
      this.fs.copyTpl(
        this.templatePath('_login-spec.js'),
        this.destinationPath('test/spec/controllers/login-spec.js'),
        context
      );

      // Copy App Assets: Root
      this.fs.copyTpl(
        this.templatePath('_app.js'),
        this.destinationPath('app/scripts/app.js'),
        context
      );
      this.fs.copyTpl(
        this.templatePath('_index.html'),
        this.destinationPath('app/index.html'),
        context
      );
      this.fs.copy(
        this.templatePath('robots.txt'),
        this.destinationPath('app/robots.txt')
      );

      // Copy App Assets: Controllers
      this.fs.copyTpl(
        this.templatePath('controllers/*'),
        this.destinationPath('app/scripts/controllers/'),
        context
      );

      // Copy App Assets: Styles
      this.fs.copy(
        this.templatePath('_main.less'),
        this.destinationPath('app/styles/main.less')
      );
      this.fs.copy(
        this.templatePath('csslintrc'),
        this.destinationPath('.csslintrc')
      );

      // Copy App Assets: Views
      this.fs.copy(
        this.templatePath('views/*'),
        this.destinationPath('app/views/')
      );
    },

    projectfiles: function () {
      this.fs.copy(
        this.templatePath('editorconfig'),
        this.destinationPath('.editorconfig')
      );
      this.fs.copy(
        this.templatePath('jshintrc'),
        this.destinationPath('.jshintrc')
      );
    }
  },

  install: function () {
    this.installDependencies({
      skipInstall: this.options['skip-install']
    });
  }
});
